Index: trunk/src/com/kitfox/svg/SVGCache.java
===================================================================
--- trunk/src/com/kitfox/svg/SVGCache.java	(revision 17332)
+++ trunk/src/com/kitfox/svg/SVGCache.java	(revision 17333)
@@ -38,5 +38,5 @@
 
 /**
- * A convienience singleton for allowing all classes to access a common SVG universe.
+ * A convenient singleton for allowing all classes to access a common SVG universe.
  *
  * @author kitfox
Index: trunk/src/com/kitfox/svg/SVGElement.java
===================================================================
--- trunk/src/com/kitfox/svg/SVGElement.java	(revision 17332)
+++ trunk/src/com/kitfox/svg/SVGElement.java	(revision 17333)
@@ -88,5 +88,5 @@
     protected String cssClass = null;
     /**
-     * Styles defined for this elemnt via the <b>style</b> attribute.
+     * Styles defined for this element via the <b>style</b> attribute.
      */
     private Map<String, String> inlineStyles = Collections.emptyMap();
@@ -115,5 +115,5 @@
      * This element may override the URI we resolve against with an xml:base
      * attribute. If so, a copy is placed here. Otherwise, we defer to our
-     * parent for the reolution base
+     * parent for the resolution base
      */
     protected URI xmlBase = null;
Index: trunk/src/com/kitfox/svg/pathcmd/Arc.java
===================================================================
--- trunk/src/com/kitfox/svg/pathcmd/Arc.java	(revision 17332)
+++ trunk/src/com/kitfox/svg/pathcmd/Arc.java	(revision 17333)
@@ -43,5 +43,5 @@
 /**
  * This is a little used SVG function, as most editors will save curves as 
- * Beziers.  To reduce the need to rely on the Batik library, this functionallity
+ * Beziers.  To reduce the need to rely on the Batik library, this functionality
  * is being bypassed for the time being.  In the future, it would be nice to
  * extend the GeneralPath command to include the arcTo ability provided by Batik.
Index: trunk/src/com/kitfox/svg/xml/StyleAttribute.java
===================================================================
--- trunk/src/com/kitfox/svg/xml/StyleAttribute.java	(revision 17332)
+++ trunk/src/com/kitfox/svg/xml/StyleAttribute.java	(revision 17333)
@@ -55,10 +55,10 @@
     static final Pattern patternUrl = Pattern.compile("\\s*url\\((.*)\\)\\s*");
     static final Matcher matchFpNumUnits = Pattern.compile("\\s*([-+]?((\\d*\\.\\d+)|(\\d+))([-+]?[eE]\\d+)?)\\s*(px|cm|mm|in|pc|pt|em|ex)\\s*").matcher("");
-    
+
     String name;
     String stringValue;
 
-    boolean colorCompatable = false;
-    boolean urlCompatable = false;
+    boolean colorCompatible = false;
+    boolean urlCompatible = false;
 
     /** Creates a new instance of StyleAttribute */
@@ -67,6 +67,6 @@
         this(null, null);
     }
-    
-    public StyleAttribute(String name) 
+
+    public StyleAttribute(String name)
     {
         this(name, null);
@@ -239,7 +239,7 @@
         return getURIValue(null);
     }
-    
+
     /**
-     * Parse this sytle attribute as a URL and return it in URI form resolved
+     * Parse this style attribute as a URL and return it in URI form resolved
      * against the passed base.
      *
Index: trunk/src/com/kitfox/svg/xml/XMLParseUtil.java
===================================================================
--- trunk/src/com/kitfox/svg/xml/XMLParseUtil.java	(revision 17332)
+++ trunk/src/com/kitfox/svg/xml/XMLParseUtil.java	(revision 17333)
@@ -168,6 +168,6 @@
      * Scans an input string for double values.  For each value found, places
      * in a list.  This method regards any characters not part of a floating
-     * point value to be seperators.  Thus this will parse whitespace seperated,
-     * comma seperated, and many other separation schemes correctly.
+     * point value to be separators.  Thus this will parse whitespace separated,
+     * comma separated, and many other separation schemes correctly.
      */
     public synchronized static double[] parseDoubleList(String list)
Index: trunk/src/org/openstreetmap/josm/actions/AbstractPasteAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/AbstractPasteAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/AbstractPasteAction.java	(revision 17333)
@@ -73,5 +73,5 @@
         MapView mapView = MainApplication.getMap().mapView;
         EastNorth mPosition = mapView.getCenter();
-        // We previously checked for modifier to know if the action has been trigerred via shortcut or via menu
+        // We previously checked for modifier to know if the action has been triggered via shortcut or via menu
         // But this does not work if the shortcut is changed to a single key (see #9055)
         // Observed behaviour: getActionCommand() returns Action.NAME when triggered via menu, but shortcut text when triggered with it
Index: trunk/src/org/openstreetmap/josm/actions/ExpertToggleAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/ExpertToggleAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/ExpertToggleAction.java	(revision 17333)
@@ -53,5 +53,5 @@
 
     /**
-     * Register a expert mode change listener, and optionnally fires it.
+     * Register a expert mode change listener, and optionally fires it.
      * @param listener the listener. Ignored if null.
      * @param fireWhenAdding if true, the listener will be fired immediately after added
Index: trunk/src/org/openstreetmap/josm/actions/ReverseWayAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/ReverseWayAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/ReverseWayAction.java	(revision 17333)
@@ -67,5 +67,5 @@
         /**
          * Gets the commands that will be required to do a full way reversal including changing the tags
-         * @return The comamnds
+         * @return The commands
          */
         public Collection<Command> getCommands() {
Index: trunk/src/org/openstreetmap/josm/actions/ToggleAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/ToggleAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/ToggleAction.java	(revision 17333)
@@ -18,5 +18,5 @@
 
 /**
- * Abtract class for Toggle Actions.
+ * Abstract class for Toggle Actions.
  * @since 6220
  */
@@ -116,9 +116,10 @@
 
     /**
-     * Toggles the selcted action state, if needed according to the ActionEvent that trigerred the action.
-     * This method will do nothing if the action event comes from a Swing component supporting the SELECTED_KEY property because
-     * the component already set the selected state.
-     * This method needs to be called especially if the action is associated with a keyboard shortcut to ensure correct selected state.
-     * @param e ActionEvent that trigerred the action
+     * Toggles the selected action state, if needed according to the ActionEvent that triggered the action.
+     * This method will do nothing if the action event comes from a Swing component
+     * supporting the SELECTED_KEY property because the component already set the selected state.
+     * This method needs to be called especially if the action is associated with a keyboard
+     * shortcut to ensure correct selected state.
+     * @param e ActionEvent that triggered the action
      * @see <a href="https://docs.oracle.com/javase/8/docs/api/javax/swing/Action.html">Interface Action</a>
      */
Index: trunk/src/org/openstreetmap/josm/actions/downloadtasks/AbstractDownloadTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/downloadtasks/AbstractDownloadTask.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/downloadtasks/AbstractDownloadTask.java	(revision 17333)
@@ -119,5 +119,5 @@
      * Determines if the given URL is accepted by {@link #getPatterns}.
      * Can be overridden for more complex checking logic.
-     * @param url URL to donwload
+     * @param url URL to download
      * @return {@code true} if this URL is accepted
      */
Index: trunk/src/org/openstreetmap/josm/actions/downloadtasks/ChangesetHeaderDownloadTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/downloadtasks/ChangesetHeaderDownloadTask.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/downloadtasks/ChangesetHeaderDownloadTask.java	(revision 17333)
@@ -21,5 +21,5 @@
 
 /**
- * This is an asynchronous task for downloading a collection of changests from the OSM server.
+ * This is an asynchronous task for downloading a collection of changesets from the OSM server.
  *
  * The  task only downloads the changeset properties without the changeset content. It
Index: trunk/src/org/openstreetmap/josm/actions/mapmode/ExtrudeAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/mapmode/ExtrudeAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/actions/mapmode/ExtrudeAction.java	(revision 17333)
@@ -124,5 +124,5 @@
     private int initialMoveDelay = 200;
     /**
-     * The minimal shift of mouse (in pixels) befire something counts as move
+     * The minimal shift of mouse (in pixels) before something counts as move
      */
     private int initialMoveThreshold = 1;
Index: trunk/src/org/openstreetmap/josm/command/Command.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/Command.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/command/Command.java	(revision 17333)
@@ -240,5 +240,5 @@
      * Ensures that all primitives that are participating in this command belong to the affected data set.
      *
-     * Commands may use this in their update methods to check the consitency of the primitives they operate on.
+     * Commands may use this in their update methods to check the consistency of the primitives they operate on.
      * @throws AssertionError if no {@link DataSet} is set or if any primitive does not belong to that dataset.
      */
Index: trunk/src/org/openstreetmap/josm/command/RotateCommand.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/RotateCommand.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/command/RotateCommand.java	(revision 17333)
@@ -37,5 +37,5 @@
      * Assign the initial object set, compute pivot point and initial rotation angle.
      * @param objects objects to fetch nodes from
-     * @param currentEN cuurent eats/north
+     * @param currentEN current east/north
      */
     public RotateCommand(Collection<? extends OsmPrimitive> objects, EastNorth currentEN) {
@@ -51,5 +51,5 @@
     /**
      * Get angle between the horizontal axis and the line formed by the pivot and given point.
-     * @param currentEN cuurent eats/north
+     * @param currentEN current east/north
      * @return angle between the horizontal axis and the line formed by the pivot and given point
      **/
Index: trunk/src/org/openstreetmap/josm/command/ScaleCommand.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/ScaleCommand.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/command/ScaleCommand.java	(revision 17333)
@@ -37,5 +37,5 @@
      * the "align nodes in circle" action.
      * @param objects objects to fetch nodes from
-     * @param currentEN cuurent eats/north
+     * @param currentEN current east/north
      */
     public ScaleCommand(Collection<? extends OsmPrimitive> objects, EastNorth currentEN) {
Index: trunk/src/org/openstreetmap/josm/command/conflict/VersionConflictResolveCommand.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/conflict/VersionConflictResolveCommand.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/command/conflict/VersionConflictResolveCommand.java	(revision 17333)
@@ -60,5 +60,5 @@
                     (int) Math.max(myVersion, theirVersion)
             );
-            // update visiblity state
+            // update visibility state
             if (theirVersion >= myVersion) {
                 conflict.getMy().setVisible(conflict.getTheir().isVisible());
Index: trunk/src/org/openstreetmap/josm/data/coor/LatLon.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/coor/LatLon.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/coor/LatLon.java	(revision 17333)
@@ -71,5 +71,5 @@
      * The number format used for high precision coordinates
      */
-    public static final DecimalFormat cDdHighPecisionFormatter;
+    public static final DecimalFormat cDdHighPrecisionFormatter;
     static {
         // Don't use the localized decimal separator. This way we can present
@@ -77,6 +77,6 @@
         cDdFormatter = (DecimalFormat) NumberFormat.getInstance(Locale.UK);
         cDdFormatter.applyPattern("###0.0######");
-        cDdHighPecisionFormatter = (DecimalFormat) NumberFormat.getInstance(Locale.UK);
-        cDdHighPecisionFormatter.applyPattern("###0.0##########");
+        cDdHighPrecisionFormatter = (DecimalFormat) NumberFormat.getInstance(Locale.UK);
+        cDdHighPrecisionFormatter.applyPattern("###0.0##########");
     }
 
Index: trunk/src/org/openstreetmap/josm/data/gpx/GpxConstants.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/gpx/GpxConstants.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/gpx/GpxConstants.java	(revision 17333)
@@ -136,5 +136,5 @@
 
     /** Creation/modification timestamp for the point.
-     *  Date and time in are in Univeral Coordinated Time (UTC), not local time!
+     *  Date and time in are in Coordinated Universal Time (UTC), not local time!
      *  Conforms to ISO 8601 specification for date/time representation.
      *  Fractional seconds are allowed for millisecond timing in tracklogs. */
Index: trunk/src/org/openstreetmap/josm/data/osm/DataSet.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/DataSet.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/DataSet.java	(revision 17333)
@@ -887,5 +887,5 @@
      * {@link DataSetListener#dataChanged(DataChangedEvent event)} event is triggered after end of changes
      * <br>
-     * Typical usecase should look like this:
+     * Typical use case should look like this:
      * <pre>
      * ds.beginUpdate();
@@ -906,5 +906,5 @@
      * Must be called after a previous call to {@link #beginUpdate()} to fire change events.
      * <br>
-     * Typical usecase should look like this:
+     * Typical use case should look like this:
      * <pre>
      * ds.beginUpdate();
@@ -1149,5 +1149,5 @@
                             this, new LinkedHashSet<>(from.dataSources), from.dataSources.stream());
                     if (from.dataSources.stream().filter(dataSource -> !dataSources.contains(dataSource))
-                            .map(dataSources::add).filter(Boolean.TRUE::equals).count() > 0) {
+                            .anyMatch(dataSources::add)) {
                         cachedDataSourceArea = null;
                         cachedDataSourceBounds = null;
@@ -1184,5 +1184,5 @@
 
     /* --------------------------------------------------------------------------------- */
-    /* interface ProjectionChangeListner                                                 */
+    /* interface ProjectionChangeListener                                                */
     /* --------------------------------------------------------------------------------- */
     @Override
Index: trunk/src/org/openstreetmap/josm/data/osm/DatasetConsistencyTest.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/DatasetConsistencyTest.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/DatasetConsistencyTest.java	(revision 17333)
@@ -69,5 +69,5 @@
 
     /**
-     * Checks for womplete ways with incomplete nodes.
+     * Checks for complete ways with incomplete nodes.
      */
     public void checkCompleteWaysWithIncompleteNodes() {
Index: trunk/src/org/openstreetmap/josm/data/osm/IPrimitive.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/IPrimitive.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/IPrimitive.java	(revision 17333)
@@ -201,5 +201,5 @@
      * Replies the OSM id of this primitive.
      * By default, returns the same value as {@link #getId}.
-     * Can be overidden by primitive implementations handling an internal id different from the OSM one.
+     * Can be overridden by primitive implementations handling an internal id different from the OSM one.
      *
      * @return the OSM id of this primitive.
Index: trunk/src/org/openstreetmap/josm/data/osm/OsmPrimitive.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/OsmPrimitive.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/OsmPrimitive.java	(revision 17333)
@@ -38,6 +38,6 @@
  *
  * Although OsmPrimitive is designed as a base class, it is not to be meant to subclass
- * it by any other than from the package {@link org.openstreetmap.josm.data.osm}. The available primitives are a fixed set that are given
- * by the server environment and not an extendible data stuff.
+ * it by any other than from the package {@link org.openstreetmap.josm.data.osm}. The available primitives are a fixed
+ * set that are given by the server environment and not an extendable data stuff.
  *
  * @author imi
Index: trunk/src/org/openstreetmap/josm/data/osm/Stylable.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/Stylable.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/Stylable.java	(revision 17333)
@@ -25,5 +25,5 @@
      * Clears the cached style.
      * This should not be called from outside. Fixing the UI to add relevant
-     * get/set functions calling this implicitely is preferred, so we can have
+     * get/set functions calling this implicitly is preferred, so we can have
      * transparent cache handling in the future.
      */
Index: trunk/src/org/openstreetmap/josm/data/osm/TagCollection.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/TagCollection.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/TagCollection.java	(revision 17333)
@@ -162,5 +162,5 @@
 
     /**
-     * Creates a clone of the tag collection <code>other</code>. Creats an empty
+     * Creates a clone of the tag collection <code>other</code>. Creates an empty
      * tag collection if <code>other</code> is null.
      *
@@ -736,5 +736,5 @@
 
     /**
-     * Get a stram for the given key.
+     * Get a stream for the given key.
      * @param key The key
      * @return The stream. An empty stream if key is <code>null</code>
Index: trunk/src/org/openstreetmap/josm/data/osm/event/AbstractDatasetChangedEvent.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/event/AbstractDatasetChangedEvent.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/event/AbstractDatasetChangedEvent.java	(revision 17333)
@@ -38,5 +38,5 @@
         RELATION_MEMBERS_CHANGED,
         /**
-         * The tags of a primitve have changed
+         * The tags of a primitive have changed
          */
         TAGS_CHANGED,
Index: trunk/src/org/openstreetmap/josm/data/osm/event/DatasetEventManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/event/DatasetEventManager.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/event/DatasetEventManager.java	(revision 17333)
@@ -22,5 +22,5 @@
  * This class allows to add DatasetListener to currently active dataset. If active
  * layer is changed, listeners are automatically registered at new active dataset
- * (it's no longer necessary to register for layer events and reregister every time
+ * (it's no longer necessary to register for layer events and re-register every time
  * new layer is selected)
  *
Index: trunk/src/org/openstreetmap/josm/data/osm/history/History.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/history/History.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/history/History.java	(revision 17333)
@@ -128,5 +128,5 @@
 
     /**
-     * Returns a new partial copy of this history, betwwen the given version numbers
+     * Returns a new partial copy of this history, between the given version numbers
      * @param fromVersion the starting version number
      * @param untilVersion the ending version number
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/MergeSourceBuildingVisitor.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/MergeSourceBuildingVisitor.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/MergeSourceBuildingVisitor.java	(revision 17333)
@@ -60,5 +60,5 @@
 
     /**
-     * Remebers a node in the "hull"
+     * Remembers a node in the "hull"
      *
      * @param n the node
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/AbstractMapRenderer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/AbstractMapRenderer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/AbstractMapRenderer.java	(revision 17333)
@@ -53,7 +53,7 @@
     protected Color nodeColor;
 
-    /** Color Preference for hightlighted objects */
+    /** Color Preference for highlighted objects */
     protected Color highlightColor;
-    /** Preference: size of virtual nodes (0 displayes display) */
+    /** Preference: size of virtual nodes (0 displays display) */
     protected int virtualNodeSize;
     /** Preference: minimum space (displayed way length) to display virtual nodes */
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ComputeStyleListWorker.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ComputeStyleListWorker.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ComputeStyleListWorker.java	(revision 17333)
@@ -51,5 +51,5 @@
      * Constructs a new {@code ComputeStyleListWorker}.
      * @param circum distance on the map in meters that 100 screen pixels represent
-     * @param nc navigatable component
+     * @param nc navigable component
      * @param input the primitives to process
      * @param output the list of styles to which styles will be added
@@ -65,5 +65,5 @@
      * Constructs a new {@code ComputeStyleListWorker}.
      * @param circum distance on the map in meters that 100 screen pixels represent
-     * @param nc navigatable component
+     * @param nc navigable component
      * @param input the primitives to process
      * @param output the list of styles to which styles will be added
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/MapRendererFactory.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/MapRendererFactory.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/MapRendererFactory.java	(revision 17333)
@@ -283,5 +283,5 @@
      * <p>Creates an instance of the currently active renderer.</p>
      * @param g Graphics
-     * @param viewport Navigatable component
+     * @param viewport Navigable component
      * @param isInactiveMode {@code true} if the paint visitor shall render OSM objects such that they look inactive
      * @return an instance of the currently active renderer
Index: trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java	(revision 17333)
@@ -48,5 +48,5 @@
  * highest performance option, and is useful for large volume transformations.
  * Non-file data sources (eg using an SQL Blob) are also supported through
- * InputStream. The RandonAccessFile option has a much smaller memory
+ * InputStream. The RandomAccessFile option has a much smaller memory
  * footprint as only the Sub Grid headers are stored in memory, but
  * transformation is slower because the file must be read a number of
Index: trunk/src/org/openstreetmap/josm/data/projection/datum/package-info.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/datum/package-info.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/projection/datum/package-info.java	(revision 17333)
@@ -2,5 +2,5 @@
 
 /**
- * Provides the classes for datums used in map projections.
+ * Provides the classes for datum used in map projections.
  */
 package org.openstreetmap.josm.data.projection.datum;
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/Mercator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/Mercator.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/Mercator.java	(revision 17333)
@@ -17,5 +17,5 @@
  * compass.
  * <p>
- * This implementation handles both the 1 and 2 stardard parallel cases.
+ * This implementation handles both the 1 and 2 standard parallel cases.
  * For 1 SP (EPSG code 9804), the line of contact is the equator.
  * For 2 SP (EPSG code 9805) lines of contact are symmetrical
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java	(revision 17333)
@@ -80,5 +80,5 @@
  *
  *   <li>{@code Hotine_Oblique_Mercator} (EPSG code 9812)<br>
- *       grid coordinates begin at the interseciton of the central line and aposphere equator,
+ *       grid coordinates begin at the intersection of the central line and aposphere equator,
  *       has {@code "rectified_grid_angle"} parameter.</li>
  *   <li>{@code Hotine_Oblique_Mercator_Azimuth_Natural_Origin} (ESRI)<br>
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagCheckerAsserts.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagCheckerAsserts.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagCheckerAsserts.java	(revision 17333)
@@ -146,5 +146,5 @@
      * Returns the set of tagchecks on which this check depends on.
      * @param check the tagcheck
-     * @param schecks the collection of tagcheks to search in
+     * @param schecks the collection of tagchecks to search in
      * @return the set of tagchecks on which this check depends on
      * @since 7881
Index: trunk/src/org/openstreetmap/josm/gui/ExceptionDialogUtil.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/ExceptionDialogUtil.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/ExceptionDialogUtil.java	(revision 17333)
@@ -30,5 +30,4 @@
 /**
  * This utility class provides static methods which explain various exceptions to the user.
- *
  */
 public final class ExceptionDialogUtil {
@@ -369,5 +368,5 @@
      * @param e the exception
      */
-    public static void explainNestedUnkonwnHostException(OsmTransferException e) {
+    public static void explainNestedUnknownHostException(OsmTransferException e) {
         showErrorDialog(
                 ExceptionUtil.explainNestedUnknownHostException(e),
@@ -392,5 +391,5 @@
         }
         if (ExceptionUtil.getNestedException(e, UnknownHostException.class) != null) {
-            explainNestedUnkonwnHostException(e);
+            explainNestedUnknownHostException(e);
             return;
         }
@@ -424,38 +423,39 @@
         if (e instanceof OsmApiException) {
             OsmApiException oae = (OsmApiException) e;
-            switch(oae.getResponseCode()) {
-            case HttpURLConnection.HTTP_PRECON_FAILED:
-                explainPreconditionFailed(oae);
-                return;
-            case HttpURLConnection.HTTP_GONE:
-                explainGoneForUnknownPrimitive(oae);
-                return;
-            case HttpURLConnection.HTTP_INTERNAL_ERROR:
-                explainInternalServerError(oae);
-                return;
-            case HttpURLConnection.HTTP_BAD_REQUEST:
-                explainBadRequest(oae);
-                return;
-            case HttpURLConnection.HTTP_NOT_FOUND:
-                explainNotFound(oae);
-                return;
-            case HttpURLConnection.HTTP_CONFLICT:
-                explainConflict(oae);
-                return;
-            case HttpURLConnection.HTTP_UNAUTHORIZED:
-                explainAuthenticationFailed(oae);
-                return;
-            case HttpURLConnection.HTTP_FORBIDDEN:
-                explainAuthorizationFailed(oae);
-                return;
-            case HttpURLConnection.HTTP_CLIENT_TIMEOUT:
-                explainClientTimeout(oae);
-                return;
-            case 509: case 429:
-                explainBandwidthLimitExceeded(oae);
-                return;
-            default:
-                explainGenericHttpException(oae);
-                return;
+            switch (oae.getResponseCode()) {
+                case HttpURLConnection.HTTP_PRECON_FAILED:
+                    explainPreconditionFailed(oae);
+                    return;
+                case HttpURLConnection.HTTP_GONE:
+                    explainGoneForUnknownPrimitive(oae);
+                    return;
+                case HttpURLConnection.HTTP_INTERNAL_ERROR:
+                    explainInternalServerError(oae);
+                    return;
+                case HttpURLConnection.HTTP_BAD_REQUEST:
+                    explainBadRequest(oae);
+                    return;
+                case HttpURLConnection.HTTP_NOT_FOUND:
+                    explainNotFound(oae);
+                    return;
+                case HttpURLConnection.HTTP_CONFLICT:
+                    explainConflict(oae);
+                    return;
+                case HttpURLConnection.HTTP_UNAUTHORIZED:
+                    explainAuthenticationFailed(oae);
+                    return;
+                case HttpURLConnection.HTTP_FORBIDDEN:
+                    explainAuthorizationFailed(oae);
+                    return;
+                case HttpURLConnection.HTTP_CLIENT_TIMEOUT:
+                    explainClientTimeout(oae);
+                    return;
+                case 509:
+                case 429:
+                    explainBandwidthLimitExceeded(oae);
+                    return;
+                default:
+                    explainGenericHttpException(oae);
+                    return;
             }
         }
Index: trunk/src/org/openstreetmap/josm/gui/MapFrameListener.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MapFrameListener.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/MapFrameListener.java	(revision 17333)
@@ -11,5 +11,5 @@
 
     /**
-     * Called after Main.mapFrame is initalized. (After the first data is loaded).
+     * Called after Main.mapFrame is initialized. (After the first data is loaded).
      * You can use this callback to tweak the newFrame to your needs, as example install
      * an alternative Painter.
Index: trunk/src/org/openstreetmap/josm/gui/MapMover.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MapMover.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/MapMover.java	(revision 17333)
@@ -124,5 +124,5 @@
     /**
      * Constructs a new {@code MapMover}.
-     * @param navComp the navigatable component
+     * @param navComp the navigable component
      * @since 11713
      */
Index: trunk/src/org/openstreetmap/josm/gui/MapViewState.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MapViewState.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/MapViewState.java	(revision 17333)
@@ -714,5 +714,5 @@
         /**
          * Gets the real bounds that enclose this rectangle.
-         * This is computed respecting that the borders of this rectangle may not be a straignt line in latlon coordinates.
+         * This is computed respecting that the borders of this rectangle may not be a straight line in latlon coordinates.
          * @return The bounds.
          * @since 10458
Index: trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java	(revision 17333)
@@ -143,5 +143,5 @@
         MainApplication.getLayerManager().addActiveLayerChangeListener(this);
 
-        new SlippyMapControler(this, this);
+        new SlippyMapController(this, this);
     }
 
@@ -247,5 +247,5 @@
 
     /**
-     * Handles a {@link SlippyMapControler#mouseMoved} event
+     * Handles a {@link SlippyMapController#mouseMoved} event
      * @param point The point in the view
      */
Index: trunk/src/org/openstreetmap/josm/gui/conflict/pair/AbstractListMerger.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/pair/AbstractListMerger.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/pair/AbstractListMerger.java	(revision 17333)
@@ -89,5 +89,5 @@
     protected abstract JScrollPane buildTheirElementsTable();
 
-    protected JScrollPane embeddInScrollPane(JTable table) {
+    protected JScrollPane embedInScrollPane(JTable table) {
         JScrollPane pane = new JScrollPane(table);
         if (adjustmentSynchronizer == null) {
Index: trunk/src/org/openstreetmap/josm/gui/conflict/pair/IConflictResolver.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/pair/IConflictResolver.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/pair/IConflictResolver.java	(revision 17333)
@@ -7,5 +7,6 @@
 
 /**
- * The conflict resolver receives the result of a {@link ConflictDialog}. It should then apply the resulution the user selected.
+ * The conflict resolver receives the result of a {@link ConflictDialog}.
+ * It should then apply the resolution the user selected.
  */
 public interface IConflictResolver {
Index: trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMergeModel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMergeModel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMergeModel.java	(revision 17333)
@@ -19,5 +19,5 @@
 
 /**
- * The model for merging two lists of way nodess
+ * The model for merging two lists of way nodes
  * @since 1622
  */
Index: trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMerger.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMerger.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/pair/nodes/NodeListMerger.java	(revision 17333)
@@ -32,5 +32,5 @@
                 model.getMySelectionModel()
         );
-        return embeddInScrollPane(myEntriesTable);
+        return embedInScrollPane(myEntriesTable);
     }
 
@@ -43,5 +43,5 @@
                 model.getMergedSelectionModel()
         );
-        return embeddInScrollPane(mergedEntriesTable);
+        return embedInScrollPane(mergedEntriesTable);
     }
 
@@ -54,5 +54,5 @@
                 model.getTheirSelectionModel()
         );
-        return embeddInScrollPane(theirEntriesTable);
+        return embedInScrollPane(theirEntriesTable);
     }
 
Index: trunk/src/org/openstreetmap/josm/gui/conflict/pair/relation/RelationMemberMerger.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/pair/relation/RelationMemberMerger.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/pair/relation/RelationMemberMerger.java	(revision 17333)
@@ -32,5 +32,5 @@
                 model.getMySelectionModel()
         );
-        return embeddInScrollPane(myEntriesTable);
+        return embedInScrollPane(myEntriesTable);
     }
 
@@ -44,5 +44,5 @@
         );
         mergedEntriesTable.putClientProperty("terminateEditOnFocusLost", Boolean.TRUE);
-        return embeddInScrollPane(mergedEntriesTable);
+        return embedInScrollPane(mergedEntriesTable);
     }
 
@@ -55,5 +55,5 @@
                 model.getTheirSelectionModel()
         );
-        return embeddInScrollPane(theirEntriesTable);
+        return embedInScrollPane(theirEntriesTable);
     }
 
Index: trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueCellEditor.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueCellEditor.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueCellEditor.java	(revision 17333)
@@ -30,5 +30,5 @@
  *
  * The editor responds intercepts some keys and interprets them as navigation keys. It
- * forwards navigation events to {@link NavigationListener}s registred with this editor.
+ * forwards navigation events to {@link NavigationListener}s registered with this editor.
  * You should register the parent table using this editor as {@link NavigationListener}.
  *
Index: trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueResolutionDecision.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueResolutionDecision.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/tags/MultiValueResolutionDecision.java	(revision 17333)
@@ -121,5 +121,5 @@
      * sets a new value for this
      *
-     * @param value the new vlaue
+     * @param value the new value
      */
     public void setNew(String value) {
Index: trunk/src/org/openstreetmap/josm/gui/conflict/tags/TagConflictResolverModel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/tags/TagConflictResolverModel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/tags/TagConflictResolverModel.java	(revision 17333)
@@ -202,5 +202,5 @@
 
     /**
-     * Gets the number of reamining conflicts.
+     * Gets the number of remaining conflicts.
      * @return The number
      */
Index: trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java	(revision 17333)
@@ -145,5 +145,5 @@
 
     /**
-     * Tests wheter this set contains any primitives that have invalid data.
+     * Tests whether this set contains any primitives that have invalid data.
      * @return <code>true</code> if invalid data is contained in this set.
      */
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/ChangesetDialog.java	(revision 17333)
@@ -71,5 +71,5 @@
  * <ul>
  *   <li>the list of changesets the currently selected objects are assigned to</li>
- *   <li>the list of changesets objects in the current data layer are assigend to</li>
+ *   <li>the list of changesets objects in the current data layer are assigned to</li>
  * </ul>
  *
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetCacheManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetCacheManager.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetCacheManager.java	(revision 17333)
@@ -228,5 +228,5 @@
      * in the changeset table.
      *
-     * @return changset actions panel
+     * @return changeset actions panel
      */
     protected JPanel buildChangesetTableActionPanel() {
@@ -717,5 +717,5 @@
 
     /**
-     * Selects the changesets  in <code>changests</code>, provided the
+     * Selects the changesets  in <code>changesets</code>, provided the
      * respective changesets are already present in the local changeset cache.
      *
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetDiscussionTableCellRenderer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetDiscussionTableCellRenderer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/changeset/ChangesetDiscussionTableCellRenderer.java	(revision 17333)
@@ -12,5 +12,5 @@
 
 /**
- * The cell renderer for the changeset dicussion table
+ * The cell renderer for the changeset discussion table
  * @since 7715
  */
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/relation/RelationEditorHooks.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/relation/RelationEditorHooks.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/relation/RelationEditorHooks.java	(revision 17333)
@@ -35,5 +35,5 @@
      * @param group The group to add
      */
-    public static void addActionsToSelectio(IRelationEditorActionGroup group) {
+    public static void addActionsToSelection(IRelationEditorActionGroup group) {
         selectionActions.add(group);
     }
Index: trunk/src/org/openstreetmap/josm/gui/download/BookmarkList.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/download/BookmarkList.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/download/BookmarkList.java	(revision 17333)
@@ -88,5 +88,5 @@
 
         /**
-         * Constructs a new unamed {@code Bookmark} for the given area.
+         * Constructs a new unnamed {@code Bookmark} for the given area.
          * @param area The bookmark area
          */
Index: trunk/src/org/openstreetmap/josm/gui/download/DownloadSourceSizingPolicy.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/download/DownloadSourceSizingPolicy.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/download/DownloadSourceSizingPolicy.java	(revision 17333)
@@ -63,5 +63,6 @@
      * The height of this component is given by a preference entry.
      * <p>
-     * Mind that using a preferred component size is not possible in this case, since the preference entry needs to have a onstant default value.
+     * Mind that using a preferred component size is not possible in this case,
+     * since the preference entry needs to have a constant default value.
      */
     class AdjustableDownloadSizePolicy implements DownloadSourceSizingPolicy {
Index: trunk/src/org/openstreetmap/josm/gui/draw/SymbolShape.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/draw/SymbolShape.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/draw/SymbolShape.java	(revision 17333)
@@ -25,5 +25,5 @@
     CIRCLE("circle", 1, 0),
     /**
-     * A triangle with sides of equal lengh
+     * A triangle with sides of equal length
      */
     TRIANGLE("triangle", 3, Math.PI / 2),
Index: trunk/src/org/openstreetmap/josm/gui/help/HyperlinkHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/help/HyperlinkHandler.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/help/HyperlinkHandler.java	(revision 17333)
@@ -26,5 +26,5 @@
 
 /**
- * Handles cliks on hyperlinks inside {@link HelpBrowser}.
+ * Handles clicks on hyperlinks inside {@link HelpBrowser}.
  * @since 14807
  */
Index: trunk/src/org/openstreetmap/josm/gui/history/VersionTable.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/VersionTable.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/history/VersionTable.java	(revision 17333)
@@ -331,5 +331,5 @@
         /**
          * Constructs a new {@code AlignedRenderer}.
-         * @param hAlignment Horizontal alignement. One of the following constants defined in SwingConstants:
+         * @param hAlignment Horizontal alignment. One of the following constants defined in SwingConstants:
          *        LEFT, CENTER (the default for image-only labels), RIGHT, LEADING (the default for text-only labels) or TRAILING
          */
Index: trunk/src/org/openstreetmap/josm/gui/io/CustomConfigurator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/io/CustomConfigurator.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/io/CustomConfigurator.java	(revision 17333)
@@ -186,5 +186,5 @@
      * Default values are not saved.
      * @param filename - where to export
-     * @param append - if true, resulting file cause appending to exuisting preferences
+     * @param append - if true, resulting file cause appending to existing preferences
      * @param keys - which preferences keys you need to export ("imagery.entries", for example)
      */
@@ -200,6 +200,6 @@
      * Preference keys matching specified pattern are saved
      * @param fileName - where to export
-     * @param append - if true, resulting file cause appending to exuisting preferences
-     * @param pattern - Regexp pattern forh preferences keys you need to export (".*imagery.*", for example)
+     * @param append - if true, resulting file cause appending to existing preferences
+     * @param pattern - Regexp pattern for preferences keys you need to export (".*imagery.*", for example)
      */
     public static void exportPreferencesKeysByPatternToFile(String fileName, boolean append, String pattern) {
Index: trunk/src/org/openstreetmap/josm/gui/layer/LayerManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/LayerManager.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/layer/LayerManager.java	(revision 17333)
@@ -190,5 +190,6 @@
 
     /**
-     * This is the list of layers we manage. The list is unmodifyable. That way, read access does not need to be synchronized.
+     * This is the list of layers we manage. The list is unmodifiable. That way, read access does
+     * not need to be synchronized.
      *
      * It is only changed in the EDT.
Index: trunk/src/org/openstreetmap/josm/gui/layer/NativeScaleLayer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/NativeScaleLayer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/layer/NativeScaleLayer.java	(revision 17333)
@@ -192,5 +192,5 @@
          * Get new scale for zoom in/out with a ratio at a number of times.
          * Used by mousewheel zoom where wheel can step more than one between events.
-         * @param scale previois scale
+         * @param scale previous scale
          * @param ratio user defined zoom ratio
          * @param times number of times to zoom
Index: trunk/src/org/openstreetmap/josm/gui/layer/gpx/ImportImagesAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/gpx/ImportImagesAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/layer/gpx/ImportImagesAction.java	(revision 17333)
@@ -26,5 +26,5 @@
 
 /**
- * An aciton that imports images along a GPX path
+ * An action that imports images along a GPX path
  */
 public class ImportImagesAction extends AbstractAction {
Index: trunk/src/org/openstreetmap/josm/gui/layer/imagery/FlushTileCacheAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/imagery/FlushTileCacheAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/layer/imagery/FlushTileCacheAction.java	(revision 17333)
@@ -39,10 +39,10 @@
             @Override
             protected void finish() {
-                // empty - flush is instaneus
+                // empty - flush is instantaneous
             }
 
             @Override
             protected void cancel() {
-                // empty - flush is instaneus
+                // empty - flush is instantaneous
             }
         }.run();
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyles.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyles.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyles.java	(revision 17333)
@@ -147,5 +147,5 @@
      * @param osm OSM primitive
      * @param scale scale
-     * @param nc navigatable component
+     * @param nc navigable component
      * @return pair containing style list and range
      * @since 13810 (signature)
@@ -239,5 +239,5 @@
      * @param osm OSM primitive
      * @param scale scale
-     * @param nc navigatable component
+     * @param nc navigable component
      * @return pair containing style list and range
      */
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/LineElement.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/LineElement.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/LineElement.java	(revision 17333)
@@ -58,5 +58,5 @@
     public float realWidth;
     /**
-     * A flag indicating if the direction arrwos should be painted. Should not be accessed directly
+     * A flag indicating if the direction arrows should be painted. Should not be accessed directly
      */
     public boolean wayDirectionArrows;
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/Symbol.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/Symbol.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/Symbol.java	(revision 17333)
@@ -28,5 +28,5 @@
     public final Color strokeColor;
     /**
-     * The color to fill the interiour of the shape.
+     * The color to fill the interior of the shape.
      */
     public final Color fillColor;
@@ -38,5 +38,5 @@
      * @param stroke The stroke to use for the outline
      * @param strokeColor The color to draw the stroke with
-     * @param fillColor The color to fill the interiour of the shape.
+     * @param fillColor The color to fill the interior of the shape.
      */
     public Symbol(SymbolShape symbol, int size, Stroke stroke, Color strokeColor, Color fillColor) {
Index: trunk/src/org/openstreetmap/josm/gui/oauth/FullyAutomaticAuthorizationUI.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/oauth/FullyAutomaticAuthorizationUI.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/oauth/FullyAutomaticAuthorizationUI.java	(revision 17333)
@@ -84,5 +84,5 @@
      * Builds the panel for entering the username and password
      *
-     * @return constructed panel for the creditentials
+     * @return constructed panel for the credentials
      */
     protected VerticallyScrollablePanel buildUserNamePasswordPanel() {
Index: trunk/src/org/openstreetmap/josm/gui/oauth/SemiAutomaticAuthorizationUI.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/oauth/SemiAutomaticAuthorizationUI.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/oauth/SemiAutomaticAuthorizationUI.java	(revision 17333)
@@ -32,5 +32,5 @@
 
 /**
- * This is the UI for running a semic-automic authorisation procedure.
+ * This is the UI for running a semi-automatic authorisation procedure.
  *
  * In contrast to the fully-automatic procedure the user is dispatched to an
Index: trunk/src/org/openstreetmap/josm/gui/preferences/plugin/PluginPreferencesModel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/preferences/plugin/PluginPreferencesModel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/preferences/plugin/PluginPreferencesModel.java	(revision 17333)
@@ -163,7 +163,7 @@
 
     /**
-     * Replies the list of plugin informations to display.
-     *
-     * @return the list of plugin informations to display
+     * Replies the list of plugin information to display.
+     *
+     * @return the list of plugin information to display
      */
     public List<PluginInformation> getDisplayedPlugins() {
Index: trunk/src/org/openstreetmap/josm/gui/preferences/server/AuthenticationPreferencesPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/preferences/server/AuthenticationPreferencesPanel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/preferences/server/AuthenticationPreferencesPanel.java	(revision 17333)
@@ -36,5 +36,5 @@
     private final JRadioButton rbOAuth = new JRadioButton();
     /** the panel which contains the authentication parameters for the respective authentication scheme */
-    private final JPanel pnlAuthenticationParameteters = new JPanel(new BorderLayout());
+    private final JPanel pnlAuthenticationParameters = new JPanel(new BorderLayout());
     /** the panel for the basic authentication parameters */
     private BasicAuthenticationPreferencesPanel pnlBasicAuthPreferences;
@@ -91,5 +91,5 @@
         gc.weightx = 1.0;
         gc.weighty = 1.0;
-        add(pnlAuthenticationParameteters, gc);
+        add(pnlAuthenticationParameters, gc);
 
         //-- the two panels for authentication parameters
@@ -98,5 +98,5 @@
 
         rbBasicAuthentication.setSelected(true);
-        pnlAuthenticationParameteters.add(pnlBasicAuthPreferences, BorderLayout.CENTER);
+        pnlAuthenticationParameters.add(pnlBasicAuthPreferences, BorderLayout.CENTER);
     }
 
@@ -151,10 +151,10 @@
         public void itemStateChanged(ItemEvent e) {
             if (rbBasicAuthentication.isSelected()) {
-                pnlAuthenticationParameteters.removeAll();
-                pnlAuthenticationParameteters.add(pnlBasicAuthPreferences, BorderLayout.CENTER);
+                pnlAuthenticationParameters.removeAll();
+                pnlAuthenticationParameters.add(pnlBasicAuthPreferences, BorderLayout.CENTER);
                 pnlBasicAuthPreferences.revalidate();
             } else {
-                pnlAuthenticationParameteters.removeAll();
-                pnlAuthenticationParameteters.add(pnlOAuthPreferences, BorderLayout.CENTER);
+                pnlAuthenticationParameters.removeAll();
+                pnlAuthenticationParameters.add(pnlOAuthPreferences, BorderLayout.CENTER);
                 pnlOAuthPreferences.revalidate();
             }
Index: trunk/src/org/openstreetmap/josm/gui/preferences/server/OAuthAuthenticationPreferencesPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/preferences/server/OAuthAuthenticationPreferencesPanel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/preferences/server/OAuthAuthenticationPreferencesPanel.java	(revision 17333)
@@ -74,5 +74,5 @@
 
         cbUseForAllRequests.setText(tr("Use OAuth for all requests to {0}", OsmApi.getOsmApi().getServerUrl()));
-        cbUseForAllRequests.setToolTipText(tr("For user-based bandwith limit instead of IP-based one"));
+        cbUseForAllRequests.setToolTipText(tr("For user-based bandwidth limit instead of IP-based one"));
         pnl.add(cbUseForAllRequests, GBC.eol().fill(GBC.HORIZONTAL));
 
Index: trunk/src/org/openstreetmap/josm/gui/progress/swing/PleaseWaitProgressMonitor.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/progress/swing/PleaseWaitProgressMonitor.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/progress/swing/PleaseWaitProgressMonitor.java	(revision 17333)
@@ -216,5 +216,5 @@
 
     /**
-     * See if this task is canceleable
+     * See if this task is cancelable
      * @return <code>true</code> if it can be canceled
      */
Index: trunk/src/org/openstreetmap/josm/gui/tagging/ac/AutoCompletionList.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/tagging/ac/AutoCompletionList.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/tagging/ac/AutoCompletionList.java	(revision 17333)
@@ -105,5 +105,5 @@
 
     /**
-     * adds a colleciton of {@link AutoCompletionItem} to this list. An item is only
+     * adds a collection of {@link AutoCompletionItem} to this list. An item is only
      * added it is not null and if it does not exist in the list yet.
      *
Index: trunk/src/org/openstreetmap/josm/gui/tagging/presets/items/Roles.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/tagging/presets/items/Roles.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/tagging/presets/items/Roles.java	(revision 17333)
@@ -69,5 +69,5 @@
 
         /**
-         * Sets wether this role is required at least once in the relation.
+         * Sets whether this role is required at least once in the relation.
          * @param str "required" or "optional"
          * @throws SAXException if str is neither "required" or "optional"
@@ -81,5 +81,5 @@
 
         /**
-         * Sets wether the role name is a regular expression.
+         * Sets whether the role name is a regular expression.
          * @param str "true" or "false"
          * @throws SAXException if str is neither "true" or "false"
Index: trunk/src/org/openstreetmap/josm/gui/util/MultikeyShortcutAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/util/MultikeyShortcutAction.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/util/MultikeyShortcutAction.java	(revision 17333)
@@ -9,5 +9,5 @@
 
 /**
- * Action implementing a multikey shortcut - shorcuts like Ctrl+Alt+S,n will toggle n-th layer visibility.
+ * Action implementing a multikey shortcut - shortcuts like Ctrl+Alt+S,n will toggle n-th layer visibility.
  * @since 4595
  */
Index: trunk/src/org/openstreetmap/josm/gui/widgets/FileChooserManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/FileChooserManager.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/FileChooserManager.java	(revision 17333)
@@ -331,5 +331,6 @@
     /**
      * Opens the {@code AbstractFileChooser} that has been created.
-     * @return the {@code AbstractFileChooser} if the user effectively choses a file or directory. {@code null} if the user cancelled the dialog.
+     * @return the {@code AbstractFileChooser} if the user effectively chooses a file or directory.
+     * {@code null} if the user cancelled the dialog.
      */
     public final AbstractFileChooser openFileChooser() {
@@ -338,9 +339,12 @@
 
     /**
-     * Opens the {@code AbstractFileChooser} that has been created and waits for the user to choose a file/directory, or cancel the dialog.<br>
-     * When the user choses a file or directory, the {@code lastDirProperty} is updated to the chosen directory path.
-     *
-     * @param parent The Component used as the parent of the AbstractFileChooser. If null, uses {@code MainApplication.getMainFrame()}.
-     * @return the {@code AbstractFileChooser} if the user effectively choses a file or directory. {@code null} if the user cancelled the dialog.
+     * Opens the {@code AbstractFileChooser} that has been created and waits for the user to choose a file/directory,
+     * or cancel the dialog.<br>
+     * When the user chooses a file or directory, the {@code lastDirProperty} is updated to the chosen directory path.
+     *
+     * @param parent The Component used as the parent of the AbstractFileChooser. If null,
+     *               uses {@code MainApplication.getMainFrame()}.
+     * @return the {@code AbstractFileChooser} if the user effectively chooses
+     * a file or directory.{@code null} if the user cancelled the dialog.
      */
     public AbstractFileChooser openFileChooser(Component parent) {
Index: trunk/src/org/openstreetmap/josm/gui/widgets/SearchTextResultListPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/SearchTextResultListPanel.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/SearchTextResultListPanel.java	(revision 17333)
@@ -182,5 +182,5 @@
 
     /**
-     * Sets a listener to be invoked on ssingle click
+     * Sets a listener to be invoked on single click
      * @param clickListener The click listener
      */
Index: trunk/src/org/openstreetmap/josm/io/ChangesetQuery.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/ChangesetQuery.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/ChangesetQuery.java	(revision 17333)
@@ -236,5 +236,5 @@
      *
      * @param min the min lat/lon coordinates of the bounding box. Must not be null.
-     * @param max the max lat/lon coordiantes of the bounding box. Must not be null.
+     * @param max the max lat/lon coordinates of the bounding box. Must not be null.
      *
      * @return the restricted changeset query
@@ -278,5 +278,5 @@
     /**
      * Restricts the result to changesets which have been closed after <code>closedAfter</code> and which
-     * habe been created before <code>createdBefore</code>. Both dates are expressed relative to the current
+     * have been created before <code>createdBefore</code>. Both dates are expressed relative to the current
      * time zone.
      *
Index: trunk/src/org/openstreetmap/josm/io/ImportCancelException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/ImportCancelException.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/ImportCancelException.java	(revision 17333)
@@ -3,5 +3,5 @@
 
 /**
- * All exceptions resulting from a user cancelation during any import should implement this interface.
+ * All exceptions resulting from a user cancellation during any import should implement this interface.
  * @since 6621
  */
Index: trunk/src/org/openstreetmap/josm/io/MessageNotifier.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/MessageNotifier.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/MessageNotifier.java	(revision 17333)
@@ -90,5 +90,5 @@
                 }
             } catch (OsmApiException e) {
-                // We want to explicitely display message to user in some cases like when he has been blocked (#17722)
+                // We want to explicitly display message to user in some cases like when he has been blocked (#17722)
                 ExceptionDialogUtil.explainOsmTransferException(e);
             } catch (OsmTransferException e) {
Index: trunk/src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/MultiFetchServerObjectReader.java	(revision 17333)
@@ -409,5 +409,5 @@
 
     /**
-     * Workaround for difference in Oerpass API.
+     * Workaround for difference in Overpass API.
      * As of now (version 7.55) Overpass api doesn't return invisible objects.
      * Check if we have objects which do not appear in the dataset and fetch them from OSM instead.
Index: trunk/src/org/openstreetmap/josm/io/NoteWriter.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/NoteWriter.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/NoteWriter.java	(revision 17333)
@@ -51,6 +51,6 @@
             out.print("  <note ");
             out.print("id=\"" + note.getId() + "\" ");
-            out.print("lat=\"" + LatLon.cDdHighPecisionFormatter.format(ll.lat()) + "\" ");
-            out.print("lon=\"" + LatLon.cDdHighPecisionFormatter.format(ll.lon()) + "\" ");
+            out.print("lat=\"" + LatLon.cDdHighPrecisionFormatter.format(ll.lat()) + "\" ");
+            out.print("lon=\"" + LatLon.cDdHighPrecisionFormatter.format(ll.lon()) + "\" ");
             out.print("created_at=\"" + DateUtils.fromDate(note.getCreatedAt()) + "\" ");
             if (note.getClosedAt() != null) {
Index: trunk/src/org/openstreetmap/josm/io/OsmApi.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/OsmApi.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/OsmApi.java	(revision 17333)
@@ -72,5 +72,5 @@
 
     /**
-     * Defines whether all OSM API requests should be signed with an OAuth token (user-based bandwith limit instead of IP-based one)
+     * Defines whether all OSM API requests should be signed with an OAuth token (user-based bandwidth limit instead of IP-based one)
      */
     public static final BooleanProperty USE_OAUTH_FOR_ALL_REQUESTS = new BooleanProperty("oauth.use-for-all-requests", true);
Index: trunk/src/org/openstreetmap/josm/io/OsmWriter.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/OsmWriter.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/OsmWriter.java	(revision 17333)
@@ -239,6 +239,6 @@
     void writeLatLon(LatLon ll) {
         if (ll != null) {
-            out.print(" lat='"+LatLon.cDdHighPecisionFormatter.format(ll.lat())+
-                     "' lon='"+LatLon.cDdHighPecisionFormatter.format(ll.lon())+'\'');
+            out.print(" lat='"+LatLon.cDdHighPrecisionFormatter.format(ll.lat())+
+                     "' lon='"+LatLon.cDdHighPrecisionFormatter.format(ll.lon())+'\'');
         }
     }
Index: trunk/src/org/openstreetmap/josm/io/audio/AudioPlayer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/audio/AudioPlayer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/audio/AudioPlayer.java	(revision 17333)
@@ -171,5 +171,5 @@
      * @param url The resource to play, which must be a WAV file or stream
      * @param seconds The number of seconds into the audio to start playing
-     * @param speed Rate at which audio playes (1.0 = real time, &gt; 1 is faster)
+     * @param speed Rate at which audio plays (1.0 = real time, &gt; 1 is faster)
      * @throws InterruptedException thread interrupted
      * @throws IOException audio fault exception, e.g. can't open stream,  unhandleable audio format
@@ -184,5 +184,5 @@
      * Pauses the currently playing audio stream. Does nothing if nothing playing.
      * @throws InterruptedException thread interrupted
-     * @throws IOException audio fault exception, e.g. can't open stream,  unhandleable audio format
+     * @throws IOException audio fault exception, e.g. can't open stream, unhandleable audio format
      */
     public static void pause() throws InterruptedException, IOException {
Index: trunk/src/org/openstreetmap/josm/io/audio/JavaSoundPlayer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/audio/JavaSoundPlayer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/audio/JavaSoundPlayer.java	(revision 17333)
@@ -89,5 +89,5 @@
                     bytesToSkip -= skippedBytes;
                     if (skippedBytes == 0) {
-                        // Avoid inifinite loop
+                        // Avoid infinite loop
                         Logging.warn("Unable to skip bytes from audio input stream");
                         bytesToSkip = 0;
Index: trunk/src/org/openstreetmap/josm/io/auth/CredentialsAgentResponse.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/auth/CredentialsAgentResponse.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/auth/CredentialsAgentResponse.java	(revision 17333)
@@ -60,6 +60,6 @@
 
     /**
-     * Sets the cancelation status (authentication request canceled by user)
-     * @param canceled the cancelation status (authentication request canceled by user)
+     * Sets the cancellation status (authentication request canceled by user)
+     * @param canceled the cancellation status (authentication request canceled by user)
      */
     public void setCanceled(boolean canceled) {
Index: trunk/src/org/openstreetmap/josm/tools/KeyboardUtils.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/KeyboardUtils.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/KeyboardUtils.java	(revision 17333)
@@ -214,5 +214,5 @@
                 break;
             case "hu":
-                // Hungary, https://en.wikipedia.org/wiki/QWERTZ#Hungary
+                // Hungarian, https://en.wikipedia.org/wiki/QWERTZ#Hungary
                 result.add('0');
                 break;
Index: trunk/src/org/openstreetmap/josm/tools/Platform.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/Platform.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/Platform.java	(revision 17333)
@@ -11,5 +11,5 @@
 
     /**
-     * Unik-like platform. This is the default when the platform cannot be identified.
+     * Unix-like platform. This is the default when the platform cannot be identified.
      */
     UNIXOID {
Index: trunk/src/org/openstreetmap/josm/tools/RotationAngle.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/RotationAngle.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/RotationAngle.java	(revision 17333)
@@ -135,5 +135,5 @@
 
     /**
-     * Converts an angle diven in cardinal directions to radians.
+     * Converts an angle given in cardinal directions to radians.
      * The following values are supported: {@code n}, {@code north}, {@code ne}, {@code northeast},
      * {@code e}, {@code east}, {@code se}, {@code southeast}, {@code s}, {@code south},
Index: trunk/src/org/openstreetmap/josm/tools/StreamUtils.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/StreamUtils.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/StreamUtils.java	(revision 17333)
@@ -36,5 +36,5 @@
 
     /**
-     * Creqates a stream iterating the list in reversed order
+     * Creates a stream iterating the list in reversed order
      * @param list the list to iterate over
      * @param <T> the type of elements in the list
Index: trunk/src/org/openstreetmap/josm/tools/bugreport/ReportedException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/bugreport/ReportedException.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/bugreport/ReportedException.java	(revision 17333)
@@ -42,5 +42,5 @@
 
     /**
-     * We capture all stack traces on exception creation. This allows us to trace synchonization problems better.
+     * We capture all stack traces on exception creation. This allows us to trace synchronization problems better.
      * We cannot be really sure what happened but we at least see which threads
      */
@@ -62,5 +62,5 @@
      * Constructs a new {@code ReportedException}.
      * @param exception the cause (which is saved for later retrieval by the {@link #getCause()} method)
-     * @param caughtOnThread thread where the exception was caugth
+     * @param caughtOnThread thread where the exception was caught
      * @since 14380
      */
@@ -277,5 +277,5 @@
 
     /**
-     * Check if this is caused by an out of memory situaition
+     * Check if this is caused by an out of memory situation
      * @return <code>true</code> if it is.
      * @since 10819
Index: trunk/src/org/openstreetmap/josm/tools/template_engine/Tokenizer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/template_engine/Tokenizer.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/tools/template_engine/Tokenizer.java	(revision 17333)
@@ -49,5 +49,5 @@
     public enum TokenType { CONDITION_START, VARIABLE_START, CONTEXT_SWITCH_START, END, PIPE, APOSTROPHE, TEXT, EOF }
 
-    private final Set<Character> specialCharaters = new HashSet<>(Arrays.asList('$', '?', '{', '}', '|', '\'', '!'));
+    private final Set<Character> specialCharacters = new HashSet<>(Arrays.asList('$', '?', '{', '}', '|', '\'', '!'));
 
     private final String template;
@@ -114,5 +114,5 @@
             return new Token(TokenType.APOSTROPHE, position);
         default:
-            while (c != -1 && !specialCharaters.contains((char) c)) {
+            while (c != -1 && !specialCharacters.contains((char) c)) {
                 if (c == '\\') {
                     getChar();

Index: trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapControler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapControler.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapControler.java	(revision 17333)
@@ -28,5 +28,5 @@
  * @author Tim Haussmann
  */
-public class SlippyMapControler extends MouseAdapter {
+public class SlippyMapController extends MouseAdapter {
 
     /** A Timer for smoothly moving the map area */
@@ -61,9 +61,9 @@
 
     /**
      * Constructs a new {@code SlippyMapControler}.
      * @param navComp navigatable component
      * @param contentPane content pane
      */
-    public SlippyMapControler(SlippyMapBBoxChooser navComp, JPanel contentPane) {
+    public SlippyMapController(SlippyMapBBoxChooser navComp, JPanel contentPane) {
         iSlippyMapChooser = navComp;
         iSlippyMapChooser.addMouseListener(this);
@@ -61,9 +61,9 @@
 
     /**
-     * Constructs a new {@code SlippyMapControler}.
-     * @param navComp navigatable component
+     * Constructs a new {@code SlippyMapController}.
+     * @param navComp navigable component
      * @param contentPane content pane
      */
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java	(revision 17333)
@@ -14,8 +14,8 @@
     /**
      * Constructs a new {@code MapCSSException} with an explicit error message.
      * @param specialmessage error message
      */
-    public MapCSSException(String specialmessage) {
-        super(specialmessage);
+    public MapCSSException(String specialMessage) {
+        super(specialMessage);
     }
 
@@ -14,8 +14,8 @@
     /**
      * Constructs a new {@code MapCSSException} with an explicit error message.
-     * @param specialmessage error message
+     * @param specialMessage error message
      */
Index: trunk/src/org/openstreetmap/josm/io/OverpassDownloadReader.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/OverpassDownloadReader.java	(revision 17332)
+++ trunk/src/org/openstreetmap/josm/io/OverpassDownloadReader.java	(revision 17333)
@@ -94,5 +94,5 @@
      * @since 11916
      */
-    public enum OverpassOutpoutFormat {
+    public enum OverpassOutputFormat {
         /** Default output format: plain OSM XML */
         OSM_XML("xml"),
@@ -110,5 +110,5 @@
         private final String directive;
 
-        OverpassOutpoutFormat(String directive) {
+        OverpassOutputFormat(String directive) {
             this.directive = directive;
         }
@@ -123,11 +123,11 @@
 
         /**
          * Returns the {@code OverpassOutpoutFormat} matching the given directive.
          * @param directive directive used in {@code [out:<directive>]} statement
          * @return {@code OverpassOutpoutFormat} matching the given directive
          * @throws IllegalArgumentException in case of invalid directive
          */
-        static OverpassOutpoutFormat from(String directive) {
-            for (OverpassOutpoutFormat oof : values()) {
+        static OverpassOutputFormat from(String directive) {
+            for (OverpassOutputFormat oof : values()) {
                 if (oof.directive.equals(directive)) {
                     return oof;
@@ -140,5 +140,5 @@
     static final Pattern OUTPUT_FORMAT_STATEMENT = Pattern.compile(".*\\[out:([a-z]{3,})\\].*", Pattern.DOTALL);
 
-    static final Map<OverpassOutpoutFormat, Class<? extends AbstractReader>> outputFormatReaders = new ConcurrentHashMap<>();
+    static final Map<OverpassOutputFormat, Class<? extends AbstractReader>> outputFormatReaders = new ConcurrentHashMap<>();
 
     final String overpassServer;
@@ -165,12 +165,12 @@
      * @return the previous value associated with {@code format}, or {@code null} if there was no mapping
      */
-    public static final Class<? extends AbstractReader> registerOverpassOutpoutFormatReader(
-            OverpassOutpoutFormat format, Class<? extends AbstractReader> readerClass) {
+    public static final Class<? extends AbstractReader> registerOverpassOutputFormatReader(
+            OverpassOutputFormat format, Class<? extends AbstractReader> readerClass) {
         return outputFormatReaders.put(Objects.requireNonNull(format), Objects.requireNonNull(readerClass));
     }
 
     static {
-        registerOverpassOutpoutFormatReader(OverpassOutpoutFormat.OSM_XML, OverpassOsmReader.class);
-        registerOverpassOutpoutFormatReader(OverpassOutpoutFormat.OSM_JSON, OverpassOsmJsonReader.class);
+        registerOverpassOutputFormatReader(OverpassOutputFormat.OSM_XML, OverpassOsmReader.class);
+        registerOverpassOutputFormatReader(OverpassOutputFormat.OSM_JSON, OverpassOsmJsonReader.class);
     }
 
@@ -369,5 +369,5 @@
         Matcher m = OUTPUT_FORMAT_STATEMENT.matcher(overpassQuery);
         if (m.matches()) {
-            Class<? extends AbstractReader> readerClass = outputFormatReaders.get(OverpassOutpoutFormat.from(m.group(1)));
+            Class<? extends AbstractReader> readerClass = outputFormatReaders.get(OverpassOutputFormat.from(m.group(1)));
             if (readerClass != null) {
                 try {
@@ -123,11 +123,11 @@
 
         /**
-         * Returns the {@code OverpassOutpoutFormat} matching the given directive.
+         * Returns the {@code OverpassOutputFormat} matching the given directive.
          * @param directive directive used in {@code [out:<directive>]} statement
@@ -123,11 +123,11 @@
          * @param directive directive used in {@code [out:<directive>]} statement
-         * @return {@code OverpassOutpoutFormat} matching the given directive
+         * @return {@code OverpassOutputFormat} matching the given directive
          * @throws IllegalArgumentException in case of invalid directive
          */